% DISCLAIMER:
%   data set and matlab script for conceptual demonstration purposes only
%   not intended for commercial use
% Cy Chan, January 2011 (cychan@mit.edu)

% Script requires REGRESS and WBLFIT, available with Matlab Statistics Toolbox

figure(1); plot(logan, briggs2, '.'); title('Scatterplot of Logan vs. Briggs Field')
disp('wbl fit coeffs (training set)')
disp(wblfit(briggs2))

coeffs = regress(briggs2, [ones(length(logan), 1), logan]); % compute regression coefficients
trainEst = coeffs(1) + coeffs(2) * logan; % compute estimate of trained data using model
figure(1); hold on; plot(logan, trainEst, 'r.'); hold off;
title('Regression model applied to training set')
disp('wbl fit coeffs (model applied to training set, uncorrected)')
disp(wblfit(trainEst))

stdres = std(trainEst - briggs2); % compute std dev of residuals (can do binned residuals by speed for better simulation)
trainEstNoisy = trainEst + randn(size(trainEst)) * stdres; % add gaussian noise to help correct wbl shape parameter
trainEstNoisy(trainEstNoisy < 0.5) = 0.5; % enforce minimum speed for wblfit
disp('wbl fit coeffs (model applied to training set, noise corrected)')
disp(wblfit(trainEstNoisy))

% apply model to long-term data
briggsMonth = coeffs(1) + coeffs(2) * loganMonth;
disp('wbl fit coeffs (model applied to test set, uncorrected):')
disp(wblfit(briggsMonth))

briggsMonthNoisy = briggsMonth + randn(length(loganMonth), 1) * stdres; % add gaussian noise to help correct wbl shape parameter
briggsMonthNoisy(briggsMonthNoisy < .5) = .5; % enforce minimum speed for wblfit
figure(2); plot(loganMonth, briggsMonthNoisy, 'b.')
figure(2); hold on; plot(loganMonth, briggsMonth, 'r.'); hold off;
title('Regression model applied to test set, with and without noise correction')
disp('wbl fit coeffs (model applied to test set, noise corrected):')
disp(wblfit(briggsMonthNoisy))
